@@ -3,7 +3,7 @@ use warnings;
 
 package JMAP::Tester;
 # ABSTRACT: a JMAP client made for testing JMAP servers
-$JMAP::Tester::VERSION = '0.004';
+$JMAP::Tester::VERSION = '0.005';
 use Moo;
 
 use Encode qw(encode_utf8);
@@ -123,7 +123,7 @@ sub _set_cookie {
     1,
     $name,
     $value,
-    $self->jmap_uri->path,
+    '/',
     $self->jmap_uri->host,
     $self->jmap_uri->port,
     0,
@@ -133,6 +133,35 @@ sub _set_cookie {
   );
 }
 
+#pod =attr default_arguments
+#pod
+#pod This is a hashref of arguments to be put into each method call.  It's
+#pod especially useful for setting a default C<accountId>.  Values given in methods
+#pod passed to C<request> will override defaults.  If the value is a reference to
+#pod C<undef>, then no value will be passed for that key.
+#pod
+#pod In other words, in this situation:
+#pod
+#pod   my $tester = JMAP::Tester->new({
+#pod     ...,
+#pod     default_arguments => { a => 1, b => 2, c => 3 },
+#pod   });
+#pod
+#pod   $tester->request([
+#pod     [ eatPies => { a => 100, b => \undef } ],
+#pod   ]);
+#pod
+#pod The request will effectively be:
+#pod
+#pod   [ [ "eatPies", { "a": 100, "c": 3 }, "a" ] ]
+#pod
+#pod =cut
+
+has default_arguments => (
+  is  => 'rw',
+  default => sub {  {}  },
+);
+
 #pod =method request
 #pod
 #pod   my $result = $jtest->request([
@@ -145,9 +174,10 @@ sub _set_cookie {
 #pod left as-is.  If no client id is given, one is generated.  You can mix
 #pod explicit and autogenerated client ids.  They will never conflict.
 #pod
-#pod The arguments to methods are JSON-encoded with a L<JSON::Typist>-aware
-#pod encoder, so JSON::Typist types can be used to ensure string or number types in
-#pod the generated JSON.
+#pod The arguments to methods are JSON-encoded with a L<JSON::Typist>-aware encoder,
+#pod so JSON::Typist types can be used to ensure string or number types in the
+#pod generated JSON.  If an argument is a reference to C<undef>, it will be removed
+#pod before the method call is made.  This lets you override a default by omission.
 #pod
 #pod The return value is an object that does the L<JMAP::Tester::Result> role,
 #pod meaning it's got an C<is_success> method that returns true or false.  For now,
@@ -164,6 +194,8 @@ sub request {
   my %seen;
   my @suffixed;
 
+  my %default_args = %{ $self->default_arguments };
+
   for my $call (@$calls) {
     my $copy = [ @$call ];
     if (defined $copy->[2]) {
@@ -174,6 +206,22 @@ sub request {
       $copy->[2] = $next;
     }
 
+    my %arg = (
+      %default_args,
+      %{ $copy->[1] // {} },
+    );
+
+    for my $key (keys %arg) {
+      if ( ref $arg{$key}
+        && ref $arg{$key} eq 'SCALAR'
+        && ! defined ${ $arg{$key} }
+      ) {
+        delete $arg{$key};
+      }
+    }
+
+    $copy->[1] = \%arg;
+
     push @suffixed, $copy;
   }
 
@@ -222,7 +270,7 @@ JMAP::Tester - a JMAP client made for testing JMAP servers
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 OVERVIEW
 
@@ -273,6 +321,30 @@ Or more simply:
 
 There is also L<JMAP::Tester::Response/"as_stripped_pairs">.
 
+=head1 ATTRIBUTES
+
+=head2 default_arguments
+
+This is a hashref of arguments to be put into each method call.  It's
+especially useful for setting a default C<accountId>.  Values given in methods
+passed to C<request> will override defaults.  If the value is a reference to
+C<undef>, then no value will be passed for that key.
+
+In other words, in this situation:
+
+  my $tester = JMAP::Tester->new({
+    ...,
+    default_arguments => { a => 1, b => 2, c => 3 },
+  });
+
+  $tester->request([
+    [ eatPies => { a => 100, b => \undef } ],
+  ]);
+
+The request will effectively be:
+
+  [ [ "eatPies", { "a": 100, "c": 3 }, "a" ] ]
+
 =head1 METHODS
 
 =head2 request
@@ -287,9 +359,10 @@ server.  If the method calls have a third element (a I<client id>) then it's
 left as-is.  If no client id is given, one is generated.  You can mix
 explicit and autogenerated client ids.  They will never conflict.
 
-The arguments to methods are JSON-encoded with a L<JSON::Typist>-aware
-encoder, so JSON::Typist types can be used to ensure string or number types in
-the generated JSON.
+The arguments to methods are JSON-encoded with a L<JSON::Typist>-aware encoder,
+so JSON::Typist types can be used to ensure string or number types in the
+generated JSON.  If an argument is a reference to C<undef>, it will be removed
+before the method call is made.  This lets you override a default by omission.
 
 The return value is an object that does the L<JMAP::Tester::Result> role,
 meaning it's got an C<is_success> method that returns true or false.  For now,
